diff --git a/cli (2).c b/cli.c
index 3637067..47eed07 100644
--- a/cli (2).c	
+++ b/cli.c
@@ -52,13 +52,16 @@
 
 
 #define PRINT_HELP  "print records\r\n"                                                             \
-                    "usage: print all|config"
+                    "usage: print all|config|data"
 
 #define PRINT_ALL_HELP  "print all records\r\n"                                                     \
                         "usage: print all"
 
 #define PRINT_CFG_HELP  "print configuration\r\n"                                                   \
                         "usage: print config"
+                        
+#define PRINT_DATA_HELP "print all records with data\r\n"                                                   \
+                        "usage: print all records with data"
 
 #define WRITE_HELP  "write a record\r\n"                                                            \
                     "usage: write file_id key \"data\"\r\n"                                         \
@@ -533,11 +536,98 @@ static void gc_cmd(nrf_cli_t const * p_cli, size_t argc, char ** argv)
     }
 }
 
+static void convert_raw_data_to_human_readable(nrf_cli_t const * p_cli, uint32_t raw_data)
+{
+    nrf_cli_fprintf(p_cli, NRF_CLI_DEFAULT,
+            "|");
+    for(uint8_t i = 0; i < 4; i++)
+    {
+        nrf_cli_fprintf(p_cli, NRF_CLI_DEFAULT,
+                    "%c",
+                    (uint8_t)(raw_data >> (8 * i)));
+    }
+    nrf_cli_fprintf(p_cli, NRF_CLI_DEFAULT,
+            "|\r\n");
+}
+
+static void print_data_cmd(nrf_cli_t const * p_cli, size_t argc, char ** argv)
+{
+    fds_find_token_t tok   = {0};
+    fds_record_desc_t desc = {0};
+
+
+    while (fds_record_iterate(&desc, &tok) != FDS_ERR_NOT_FOUND)
+    {
+        
+        nrf_cli_fprintf(p_cli, NRF_CLI_DEFAULT,
+                        "rec. id\t"
+                        "\tfile id\t"
+                        "\trec. key\t"
+                        "\tlength\r\n");
+        
+        ret_code_t rc;
+        fds_flash_record_t frec = {0};
+
+        rc = fds_record_open(&desc, &frec);
+        switch (rc)
+        {
+            case FDS_SUCCESS:
+                break;
+
+            case FDS_ERR_CRC_CHECK_FAILED:
+                nrf_cli_fprintf(p_cli, NRF_CLI_ERROR, "error: CRC check failed!\r\n");
+                continue;
+
+            case FDS_ERR_NOT_FOUND:
+                nrf_cli_fprintf(p_cli, NRF_CLI_ERROR, "error: record not found!\r\n");
+                continue;
+
+            default:
+            {
+                nrf_cli_fprintf(p_cli, NRF_CLI_ERROR,
+                                "error: unexpecte error %s.\r\n",
+                                fds_err_str[rc]);
+
+                continue;
+            }
+        }
+
+        uint32_t const len = frec.p_header->length_words * sizeof(uint32_t);
+
+        nrf_cli_fprintf(p_cli, NRF_CLI_DEFAULT,
+                        " 0x%04x\t"
+                        "\t 0x%04x\t"
+                        "\t 0x%04x\t"
+                        "\t %4u bytes\r\n",
+                        frec.p_header->record_id,
+                        frec.p_header->file_id,
+                        frec.p_header->record_key,
+                        len);
+
+        uint32_t * data = (uint32_t *)frec.p_data;
+        
+        nrf_cli_fprintf(p_cli, NRF_CLI_DEFAULT, "\r\nData:\r\n");
+        for(uint32_t i; i < len / 4; i++)
+        {
+            nrf_cli_fprintf(p_cli, NRF_CLI_DEFAULT,
+                            " 0x%08x\t",
+                            *data);
+            convert_raw_data_to_human_readable(p_cli, *data);
+            data++;
+        }
+        
+        nrf_cli_fprintf(p_cli, NRF_CLI_DEFAULT, "\r\n\r\n");
+        
+        rc = fds_record_close(&desc);
+        APP_ERROR_CHECK(rc);
+    }
+}
 
 NRF_CLI_CREATE_STATIC_SUBCMD_SET(m_print)
 {
-    NRF_CLI_CMD(all,    NULL, PRINT_ALL_HELP, print_all_cmd),
-    NRF_CLI_CMD(config, NULL, PRINT_CFG_HELP, print_cfg_cmd),
+    NRF_CLI_CMD(all,        NULL, PRINT_ALL_HELP,   print_all_cmd),
+    NRF_CLI_CMD(config,     NULL, PRINT_CFG_HELP,   print_cfg_cmd),
+    NRF_CLI_CMD(data,       NULL, PRINT_DATA_HELP,  print_data_cmd),
     NRF_CLI_SUBCMD_SET_END
 };
 
